@@ -9,7 +9,7 @@ require      Exporter;
 our @ISA = qw (Exporter);
 our @EXPORT = qw (baseconfigure verbosity freezeverbosity dumper);
 
-our $VERSION = "1.25";
+our $VERSION = "1.27";
 
 $Baseobject::directfeedback=0; # for downward compatibility
 $Baseobject::quickdeath=0;
@@ -221,17 +221,12 @@ sub checkneeds {
 	return $self;
 }
 
-sub dumper {
+sub inspect {
 	my $string = Dumper(@_);
 	my ($package, $file, $line) = caller();
 	$string .= " Inspect called at: $file line $line\n";
 }
 
-sub inspect {
-	my $self = shift;
-	dumper(@_);
-}
-
 sub showallows {
 	my $self = shift;
 	return join (' ',(  (keys %{$self->{needs}}), keys %{$self->{allows}})),"\n";
@@ -337,7 +332,6 @@ sub verbose {
 	my $string = join('', @_);
 	chomp($string);
 	print STDERR "$string at $file line $line (verbose)" if verbosity >= 1;
-
 }
 
 sub debug {
